### This is a python-midi for Python 3 as was kindly made avaialble by @sniperwrb
https://github.com/sniperwrb/python-midi

### Original package/module by @vishnubob is located here:

https://github.com/vishnubob/python-midi

### Install:

unzip python-midi-master.zip

apt-get install swig

python setup.py install
